==> kafka-3.9.0-src.tgz: kafka-3.9.0-src/clients/src/main/java/org/apache/kafka/clients/admin/NewPartitionReassignment.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.clients.admin;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * A new partition reassignment, which can be applied via {@link AdminClient#alterPartitionReassignments(Map, AlterPartitionReassignmentsOptions)}.
 */
public class NewPartitionReassignment {
    private final List<Integer> targetReplicas;

    /**
     * @throws IllegalArgumentException if no replicas are supplied
     */
    public NewPartitionReassignment(List<Integer> targetReplicas) {
        if (targetReplicas == null || targetReplicas.isEmpty())
            throw new IllegalArgumentException("Cannot create a new partition reassignment without any replicas");
        this.targetReplicas = Collections.unmodifiableList(new ArrayList<>(targetReplicas));
    }

    public List<Integer> targetReplicas() {
        return targetReplicas;
    }
}

==> kafka-4.0.0-src.tgz: kafka-4.0.0-src/clients/src/main/java/org/apache/kafka/clients/admin/NewPartitionReassignment.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.clients.admin;

import java.util.List;
import java.util.Map;

/**
 * A new partition reassignment, which can be applied via {@link AdminClient#alterPartitionReassignments(Map, AlterPartitionReassignmentsOptions)}.
 */
public class NewPartitionReassignment {
    private final List<Integer> targetReplicas;

    /**
     * @throws IllegalArgumentException if no replicas are supplied
     */
    public NewPartitionReassignment(List<Integer> targetReplicas) {
        if (targetReplicas == null || targetReplicas.isEmpty())
            throw new IllegalArgumentException("Cannot create a new partition reassignment without any replicas");
        this.targetReplicas = List.copyOf(targetReplicas);
    }

    public List<Integer> targetReplicas() {
        return targetReplicas;
    }
}
